DecimalValue class

Inheritance

Constructors

DecimalValue({Decimal? defaultValue, bool isRequired = false})

Properties

defaultValue → Decimal?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Decimal?
no setterinherited
valueFormated → String
no setterinherited
valueShadowed → String
no setterinherited

Methods

doParse(String? parseValue) → Decimal?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String? parseValue) → Decimal?
inherited
parseValueTry(String? newValue) → String
inherited
set(Decimal? newValue) → void
inherited
toString() → String
A string representation of this object.
inherited
tryParse(String? parseValue) → Decimal?
inherited
validate(String? newValue) → void
inherited
validator(String? newValue) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited