GenericStringValue class

Inheritance
Implementers

Constructors

GenericStringValue({String defaultValue = "", bool isRequired = true, int? maxLenght, int? minLenght})

Properties

defaultValue → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool
finalinherited
maxLenght → int?
final
minLenght → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
no setterinherited
valueFormated → String
no setterinherited
valueShadowed → String
no setterinherited

Methods

doParse(String? parseValue) → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String? parseValue) → String
inherited
parseValueTry(String? newValue) → String
inherited
set(String newValue) → void
inherited
toString() → String
A string representation of this object.
inherited
tryParse(String? parseValue) → String?
inherited
validate(String? newValue) → void
override
validator(String? newValue) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited