IntValue class

Inheritance

Constructors

IntValue({int? defaultValue, bool isRequired = false})

Properties

defaultValue → int?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int?
no setterinherited
valueFormated → String
no setterinherited
valueShadowed → String
no setterinherited

Methods

doParse(String? parseValue) → int?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String? parseValue) → int?
inherited
parseValueTry(String? newValue) → String
inherited
set(int? newValue) → void
inherited
toString() → String
A string representation of this object.
inherited
tryParse(String? parseValue) → int?
inherited
validate(String? newValue) → void
inherited
validator(String? newValue) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited