PasswordValue class

Inheritance

Constructors

PasswordValue({int minChar = 8, int maxChar = 255, String defaultValue = "", bool mustContainNumeric = true, bool mustContainLowerChar = true, bool mustContainUpperChar = true, bool mustContainSpecialChar = false})

Properties

defaultValue → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isRequired → bool
finalinherited
maxChar → int
final
maxLenght → int?
finalinherited
minChar → int
final
minLenght → int?
finalinherited
mustContainLowerChar → bool
final
mustContainNumeric → bool
final
mustContainSpecialChar → bool
final
mustContainUpperChar → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
no setterinherited
valueFormated → String
no setterinherited
valueShadowed → String
no setterinherited

Methods

doParse(String? parseValue) → String
inherited
hasLowerChar(String str) → bool
hasNumeric(String str) → bool
hasSpecialChar(String str) → bool
hasUpperChar(String str) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String? parseValue) → String
inherited
parseValueTry(String? newValue) → String
inherited
set(String newValue) → void
inherited
toString() → String
A string representation of this object.
inherited
tryParse(String? parseValue) → String?
inherited
validate(String? newValue) → void
override
validator(String? newValue) → String?
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited